package Git::Raw::Blob;
{
  $Git::Raw::Blob::VERSION = '0.05';
}

use strict;
use warnings;

=head1 NAME

Git::Raw::Blob - Git blob class

=head1 VERSION

version 0.05

=head1 DESCRIPTION

Some description here...

=head1 METHODS

=head2 content( )

Retrieve the raw content of a blob.

=head1 AUTHOR

Alessandro Ghedini <alexbio@cpan.org>

=head1 LICENSE AND COPYRIGHT

Copyright 2012 Alessandro Ghedini.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1; # End of Git::Raw::Blob
